# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ...core.datetime_utils import serialize_datetime
from ...core.pydantic_utilities import deep_union_pydantic_dicts, pydantic_v1
from .completion_choice import CompletionChoice
from .usage_stats import UsageStats


class CompletionResponse(pydantic_v1.BaseModel):
    """
    Represents a completion response from the API.
    Note: both the streamed and non-streamed response objects
    share the same shape (unlike the chat endpoint).
    """

    choices: typing.List[CompletionChoice] = pydantic_v1.Field()
    """
    A list of completion choices.
    """

    created: int = pydantic_v1.Field()
    """
    The Unix timestamp (in seconds) of when the completion was created.
    """

    id: str = pydantic_v1.Field()
    """
    A unique identifier for the completion.
    """

    model: str = pydantic_v1.Field()
    """
    The model used for the completion.
    """

    object: typing.Optional[typing.Any] = None
    system_fingerprint: str = pydantic_v1.Field()
    """
    The system response fingerprint.
    """

    usage: typing.Optional[UsageStats] = pydantic_v1.Field(default=None)
    """
    Usage statistics for the request.
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic_v1.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

from .types import (
    Asset,
    AssetType,
    BaseEngine,
    BaseEngineType,
    CheckpointData,
    CompleteAssetUploadResponse,
    CreateAssetResponse,
    CreateAssetResponseTransferApi,
    CreateAssetResponseTransferApi_None,
    CreateAssetResponseTransferApi_PresignedUrl,
    CreateAssetResponseTransferApi_Sts,
    Data,
    DataType,
    Data_Checkpoint,
    Data_File,
    Data_Latent,
    Data_Lora,
    Data_TextualInversion,
    Data_Vae,
    DeleteAssetResponse,
    FileData,
    FileExtension,
    FileFormat,
    FileStructure,
    HttpValidationError,
    LatentData,
    ListAssetsResponse,
    LoraData,
    NoTransferApi,
    PresignedUrlTransferApi,
    RetrieveAssetResponse,
    RetrieveAssetResponseTransferApi,
    RetrieveAssetResponseTransferApi_None,
    RetrieveAssetResponseTransferApi_PresignedUrl,
    RetrieveAssetResponseTransferApi_Sts,
    Status,
    StsTransferApi,
    TextualInversionData,
    TransferApiType,
    VaeData,
    ValidationError,
    ValidationErrorLocItem,
)
from .errors import UnprocessableEntityError

__all__ = [
    "Asset",
    "AssetType",
    "BaseEngine",
    "BaseEngineType",
    "CheckpointData",
    "CompleteAssetUploadResponse",
    "CreateAssetResponse",
    "CreateAssetResponseTransferApi",
    "CreateAssetResponseTransferApi_None",
    "CreateAssetResponseTransferApi_PresignedUrl",
    "CreateAssetResponseTransferApi_Sts",
    "Data",
    "DataType",
    "Data_Checkpoint",
    "Data_File",
    "Data_Latent",
    "Data_Lora",
    "Data_TextualInversion",
    "Data_Vae",
    "DeleteAssetResponse",
    "FileData",
    "FileExtension",
    "FileFormat",
    "FileStructure",
    "HttpValidationError",
    "LatentData",
    "ListAssetsResponse",
    "LoraData",
    "NoTransferApi",
    "PresignedUrlTransferApi",
    "RetrieveAssetResponse",
    "RetrieveAssetResponseTransferApi",
    "RetrieveAssetResponseTransferApi_None",
    "RetrieveAssetResponseTransferApi_PresignedUrl",
    "RetrieveAssetResponseTransferApi_Sts",
    "Status",
    "StsTransferApi",
    "TextualInversionData",
    "TransferApiType",
    "UnprocessableEntityError",
    "VaeData",
    "ValidationError",
    "ValidationErrorLocItem",
]



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import datetime as dt
import typing

from ...core.datetime_utils import serialize_datetime
from ...core.pydantic_utilities import deep_union_pydantic_dicts, pydantic_v1
from .base_engine import BaseEngine
from .data_type import DataType
from .file_extension import FileExtension
from .file_format import FileFormat


class Data_Checkpoint(pydantic_v1.BaseModel):
    """
    Asset data. It shows the type of data for an asset.
    """

    data_type: typing.Optional[DataType] = None
    engine: BaseEngine
    file_format: typing.Optional[FileFormat] = None
    asset_type: typing.Literal["checkpoint"] = "checkpoint"

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic_v1.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}


class Data_File(pydantic_v1.BaseModel):
    """
    Asset data. It shows the type of data for an asset.
    """

    file_format: typing.Optional[FileExtension] = None
    preview_url: typing.Optional[str] = None
    version: typing.Optional[str] = None
    asset_type: typing.Literal["file"] = "file"

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic_v1.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}


class Data_Latent(pydantic_v1.BaseModel):
    """
    Asset data. It shows the type of data for an asset.
    """

    engine: BaseEngine
    file_format: typing.Optional[FileFormat] = None
    asset_type: typing.Literal["latent"] = "latent"

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic_v1.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}


class Data_Lora(pydantic_v1.BaseModel):
    """
    Asset data. It shows the type of data for an asset.
    """

    checkpoint: typing.Optional[str] = None
    data_type: typing.Optional[DataType] = None
    engine: BaseEngine
    file_format: typing.Optional[FileFormat] = None
    trigger_words: typing.Optional[typing.List[str]] = None
    asset_type: typing.Literal["lora"] = "lora"

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic_v1.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}


class Data_TextualInversion(pydantic_v1.BaseModel):
    """
    Asset data. It shows the type of data for an asset.
    """

    data_type: typing.Optional[DataType] = None
    engine: BaseEngine
    file_format: typing.Optional[FileFormat] = None
    trigger_words: typing.Optional[typing.List[str]] = None
    asset_type: typing.Literal["textual_inversion"] = "textual_inversion"

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic_v1.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}


class Data_Vae(pydantic_v1.BaseModel):
    """
    Asset data. It shows the type of data for an asset.
    """

    data_type: typing.Optional[DataType] = None
    engine: BaseEngine
    file_format: typing.Optional[FileFormat] = None
    asset_type: typing.Literal["vae"] = "vae"

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic_v1.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}


Data = typing.Union[Data_Checkpoint, Data_File, Data_Latent, Data_Lora, Data_TextualInversion, Data_Vae]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ...core.datetime_utils import serialize_datetime
from ...core.pydantic_utilities import deep_union_pydantic_dicts, pydantic_v1
from .tune_details import TuneDetails
from .tune_result import TuneResult
from .tune_status import TuneStatus
from .tune_type import TuneType


class Tune(pydantic_v1.BaseModel):
    """
    Tune base class. This class is used to store tune information.
    """

    created_at: dt.datetime = pydantic_v1.Field()
    """
    The time this tune task was created.
    """

    deleted_at: typing.Optional[dt.datetime] = pydantic_v1.Field(default=None)
    """
    The time this tune task was deleted.
    """

    description: str = pydantic_v1.Field()
    """
    The description of the tune.
    """

    details: TuneDetails = pydantic_v1.Field()
    """
    Tune details. This field is used to store a specific tune type configurations.
    """

    id: str = pydantic_v1.Field()
    """
    The ID of the LoRA tune.
    """

    name: str = pydantic_v1.Field()
    """
    The name of the tune.
    """

    output_lora_ids: typing.List[str] = pydantic_v1.Field()
    """
    The output LoRA IDs, if the task was successful.
    """

    result: typing.Optional[TuneResult] = pydantic_v1.Field(default=None)
    """
    Tune result.
    """

    status: TuneStatus = pydantic_v1.Field()
    """
    The status of the associated task.
    """

    status_details: str = pydantic_v1.Field()
    """
    The details of the status, only used when the associated task failed.
    """

    succeeded_at: typing.Optional[dt.datetime] = pydantic_v1.Field(default=None)
    """
    The time the tune task succeeded.
    """

    tenant_id: str = pydantic_v1.Field()
    """
    The tenant who requested the LoRA tune.
    """

    tune_type: TuneType = pydantic_v1.Field()
    """
    The type of this tune.
    """

    updated_at: dt.datetime = pydantic_v1.Field()
    """
    The time this tune task was updated.
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic_v1.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import datetime as dt
import typing

from ...core.datetime_utils import serialize_datetime
from ...core.pydantic_utilities import deep_union_pydantic_dicts, pydantic_v1


class CreateAssetResponseTransferApi_None(pydantic_v1.BaseModel):
    """
    Asset transfer API type.
    """

    type: typing.Literal["none"] = "none"

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic_v1.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}


class CreateAssetResponseTransferApi_PresignedUrl(pydantic_v1.BaseModel):
    """
    Asset transfer API type.
    """

    get_url: str
    put_url: str
    type: typing.Literal["presigned-url"] = "presigned-url"

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic_v1.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}


class CreateAssetResponseTransferApi_Sts(pydantic_v1.BaseModel):
    """
    Asset transfer API type.
    """

    aws_access_key_id: str
    aws_secret_access_key: str
    aws_session_token: typing.Optional[str] = None
    s3bucket: str = pydantic_v1.Field(alias="s3_bucket")
    s3endpoint_url: typing.Optional[str] = pydantic_v1.Field(alias="s3_endpoint_url", default=None)
    s3key: str = pydantic_v1.Field(alias="s3_key")
    s3url: str = pydantic_v1.Field(alias="s3_url")
    type: typing.Literal["sts"] = "sts"

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True
        extra = pydantic_v1.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}


CreateAssetResponseTransferApi = typing.Union[
    CreateAssetResponseTransferApi_None, CreateAssetResponseTransferApi_PresignedUrl, CreateAssetResponseTransferApi_Sts
]
